==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberCallFinishTaskResultItem.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: 对外暴露api接口
 * @author: 777771
 * @date: 2019-37-26 21:37:55
 */
public class MemberCallFinishTaskResultItem {

    /**
     * 是否进行过人工标注修改 0:没有 1:有
     */
    private Long artificialChanged;

    /**
     * 通话结果人工标注值（一般指人工标注意向等级）
     */
    private String artificialResultValue;

    /**
     * 任务id
     */
    private Long callJobId;

    /**
     * 公司Id
     */
    private Long companyId;

    /**
     * 创建时间
     */
    private String gmtCreate;

    /**
     * 修改时间
     */
    private String gmtModified;

    /**
     * 结果描述
     */
    private String resultDesc;

    /**
     * 通话记录结果类型名
     */
    private String resultName;

    /**
     * 通话记录结果值
     */
    private String resultValue;

    /**
     * 分析结果别名(resultName为【客户意向等级】时标注值为意向级别 A,B,C,D,E,F)
     */
    private String resultValueAlias;

    /**
     * 客户意向等级的表述（文案与crm对应）
     */
    private String resultValueNew;

    /**
     * 通话记录Id(对应callInstanceId)
     */
    private Long sceneInstanceId;

    /**
     * 通话记录结果Id
     */
    private Long sceneInstanceResultId;

    public MemberCallFinishTaskResultItem(){
    }

    public MemberCallFinishTaskResultItem(Long artificialChanged,String artificialResultValue,Long callJobId,Long companyId,String gmtCreate,String gmtModified,String resultDesc,String resultName,String resultValue,String resultValueAlias,String resultValueNew,Long sceneInstanceId,Long sceneInstanceResultId){
        this.artificialChanged=artificialChanged;
        this.artificialResultValue=artificialResultValue;
        this.callJobId=callJobId;
        this.companyId=companyId;
        this.gmtCreate=gmtCreate;
        this.gmtModified=gmtModified;
        this.resultDesc=resultDesc;
        this.resultName=resultName;
        this.resultValue=resultValue;
        this.resultValueAlias=resultValueAlias;
        this.resultValueNew=resultValueNew;
        this.sceneInstanceId=sceneInstanceId;
        this.sceneInstanceResultId=sceneInstanceResultId;
    }

    private Long getArtificialChanged() {
        return artificialChanged;
    }

    private void setArtificialChanged(Long artificialChanged) {
        this.artificialChanged = artificialChanged;
    }
    private String getArtificialResultValue() {
        return artificialResultValue;
    }

    private void setArtificialResultValue(String artificialResultValue) {
        this.artificialResultValue = artificialResultValue;
    }
    private Long getCallJobId() {
        return callJobId;
    }

    private void setCallJobId(Long callJobId) {
        this.callJobId = callJobId;
    }
    private Long getCompanyId() {
        return companyId;
    }

    private void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    private String getGmtCreate() {
        return gmtCreate;
    }

    private void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
    private String getGmtModified() {
        return gmtModified;
    }

    private void setGmtModified(String gmtModified) {
        this.gmtModified = gmtModified;
    }
    private String getResultDesc() {
        return resultDesc;
    }

    private void setResultDesc(String resultDesc) {
        this.resultDesc = resultDesc;
    }
    private String getResultName() {
        return resultName;
    }

    private void setResultName(String resultName) {
        this.resultName = resultName;
    }
    private String getResultValue() {
        return resultValue;
    }

    private void setResultValue(String resultValue) {
        this.resultValue = resultValue;
    }
    private String getResultValueAlias() {
        return resultValueAlias;
    }

    private void setResultValueAlias(String resultValueAlias) {
        this.resultValueAlias = resultValueAlias;
    }
    private String getResultValueNew() {
        return resultValueNew;
    }

    private void setResultValueNew(String resultValueNew) {
        this.resultValueNew = resultValueNew;
    }
    private Long getSceneInstanceId() {
        return sceneInstanceId;
    }

    private void setSceneInstanceId(Long sceneInstanceId) {
        this.sceneInstanceId = sceneInstanceId;
    }
    private Long getSceneInstanceResultId() {
        return sceneInstanceResultId;
    }

    private void setSceneInstanceResultId(Long sceneInstanceResultId) {
        this.sceneInstanceResultId = sceneInstanceResultId;
    }
}

==> biostime-openapi-sdk-1.5.9.1-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/member/MemberCallFinishTaskResultItem.java <==
package global.hh.openapi.sdk.api.bean.member;


/**
 * @description: 对外暴露api接口
 * @author: 13351
 * @date: 2019-46-29 12:46:19
 */
public class MemberCallFinishTaskResultItem {

    /**
     * 是否进行过人工标注修改 0:没有 1:有
     */
    private Long artificialChanged;

    /**
     * 通话结果人工标注值（一般指人工标注意向等级）
     */
    private String artificialResultValue;

    /**
     * 任务id
     */
    private Long callJobId;

    /**
     * 公司Id
     */
    private Long companyId;

    /**
     * 创建时间
     */
    private String gmtCreate;

    /**
     * 修改时间
     */
    private String gmtModified;

    /**
     * 结果描述
     */
    private String resultDesc;

    /**
     * 通话记录结果类型名
     */
    private String resultName;

    /**
     * 通话记录结果值
     */
    private String resultValue;

    /**
     * 分析结果别名(resultName为【客户意向等级】时标注值为意向级别 A,B,C,D,E,F)
     */
    private String resultValueAlias;

    /**
     * 客户意向等级的表述（文案与crm对应）
     */
    private String resultValueNew;

    /**
     * 通话记录Id(对应callInstanceId)
     */
    private Long sceneInstanceId;

    /**
     * 通话记录结果Id
     */
    private Long sceneInstanceResultId;

    public MemberCallFinishTaskResultItem(){
    }

    public MemberCallFinishTaskResultItem(Long artificialChanged,String artificialResultValue,Long callJobId,Long companyId,String gmtCreate,String gmtModified,String resultDesc,String resultName,String resultValue,String resultValueAlias,String resultValueNew,Long sceneInstanceId,Long sceneInstanceResultId){
        this.artificialChanged=artificialChanged;
        this.artificialResultValue=artificialResultValue;
        this.callJobId=callJobId;
        this.companyId=companyId;
        this.gmtCreate=gmtCreate;
        this.gmtModified=gmtModified;
        this.resultDesc=resultDesc;
        this.resultName=resultName;
        this.resultValue=resultValue;
        this.resultValueAlias=resultValueAlias;
        this.resultValueNew=resultValueNew;
        this.sceneInstanceId=sceneInstanceId;
        this.sceneInstanceResultId=sceneInstanceResultId;
    }

    public Long getArtificialChanged() {
        return artificialChanged;
    }

    public void setArtificialChanged(Long artificialChanged) {
        this.artificialChanged = artificialChanged;
    }
    public String getArtificialResultValue() {
        return artificialResultValue;
    }

    public void setArtificialResultValue(String artificialResultValue) {
        this.artificialResultValue = artificialResultValue;
    }
    public Long getCallJobId() {
        return callJobId;
    }

    public void setCallJobId(Long callJobId) {
        this.callJobId = callJobId;
    }
    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
    public String getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(String gmtModified) {
        this.gmtModified = gmtModified;
    }
    public String getResultDesc() {
        return resultDesc;
    }

    public void setResultDesc(String resultDesc) {
        this.resultDesc = resultDesc;
    }
    public String getResultName() {
        return resultName;
    }

    public void setResultName(String resultName) {
        this.resultName = resultName;
    }
    public String getResultValue() {
        return resultValue;
    }

    public void setResultValue(String resultValue) {
        this.resultValue = resultValue;
    }
    public String getResultValueAlias() {
        return resultValueAlias;
    }

    public void setResultValueAlias(String resultValueAlias) {
        this.resultValueAlias = resultValueAlias;
    }
    public String getResultValueNew() {
        return resultValueNew;
    }

    public void setResultValueNew(String resultValueNew) {
        this.resultValueNew = resultValueNew;
    }
    public Long getSceneInstanceId() {
        return sceneInstanceId;
    }

    public void setSceneInstanceId(Long sceneInstanceId) {
        this.sceneInstanceId = sceneInstanceId;
    }
    public Long getSceneInstanceResultId() {
        return sceneInstanceResultId;
    }

    public void setSceneInstanceResultId(Long sceneInstanceResultId) {
        this.sceneInstanceResultId = sceneInstanceResultId;
    }
}
